@@ -5,13 +5,15 @@ from logging import NullHandler
 from logging.handlers import RotatingFileHandler
 import sys
 
-import aprsd
-from aprsd import messaging, packets, plugin, stats, utils
 import flask
 import flask_classful
 from flask_httpauth import HTTPBasicAuth
 from werkzeug.security import check_password_hash, generate_password_hash
 
+import aprsd
+from aprsd import messaging, packets, plugin, stats, utils
+
+
 LOG = logging.getLogger("APRSD")
 
 auth = HTTPBasicAuth()
@@ -59,6 +61,10 @@ class APRSDFlask(flask_classful.FlaskView):
             watch_count = 0
             watch_age = 0
 
+        pm = plugin.PluginManager()
+        plugins = pm.get_plugins()
+        plugin_count = len(plugins)
+
         return flask.render_template(
             "index.html",
             initial_stats=stats,
@@ -67,6 +73,7 @@ class APRSDFlask(flask_classful.FlaskView):
             config_json=json.dumps(self.config),
             watch_count=watch_count,
             watch_age=watch_age,
+            plugin_count=plugin_count,
         )
 
     @auth.login_required
