@@ -10,12 +10,14 @@ import re
 import sys
 import threading
 
-import aprsd
-from aprsd import plugin
 import click
 import update_checker
 import yaml
 
+import aprsd
+from aprsd import plugin
+
+
 LOG_LEVELS = {
     "CRITICAL": logging.CRITICAL,
     "ERROR": logging.ERROR,
@@ -102,9 +104,9 @@ DEFAULT_CONFIG_DICT = {
 }
 
 home = str(Path.home())
-DEFAULT_CONFIG_DIR = "{}/.config/aprsd/".format(home)
-DEFAULT_SAVE_FILE = "{}/.config/aprsd/aprsd.p".format(home)
-DEFAULT_CONFIG_FILE = "{}/.config/aprsd/aprsd.yml".format(home)
+DEFAULT_CONFIG_DIR = f"{home}/.config/aprsd/"
+DEFAULT_SAVE_FILE = f"{home}/.config/aprsd/aprsd.p"
+DEFAULT_CONFIG_FILE = f"{home}/.config/aprsd/aprsd.yml"
 
 
 def synchronized(wrapped):
@@ -229,7 +231,7 @@ def create_default_config():
     config_file_expanded = os.path.expanduser(DEFAULT_CONFIG_FILE)
     config_dir = os.path.dirname(config_file_expanded)
     if not os.path.exists(config_dir):
-        click.echo("Config dir '{}' doesn't exist, creating.".format(config_dir))
+        click.echo(f"Config dir '{config_dir}' doesn't exist, creating.")
         mkdir_p(config_dir)
     with open(config_file_expanded, "w+") as cf:
         cf.write(dump_default_cfg())
@@ -245,7 +247,7 @@ def get_config(config_file):
     else:
         if config_file == DEFAULT_CONFIG_FILE:
             click.echo(
-                "{} is missing, creating config file".format(config_file_expanded),
+                f"{config_file_expanded} is missing, creating config file",
             )
             create_default_config()
             msg = (
@@ -256,7 +258,7 @@ def get_config(config_file):
         else:
             # The user provided a config file path different from the
             # Default, so we won't try and create it, just bitch and bail.
-            msg = "Custom config file '{}' is missing.".format(config_file)
+            msg = f"Custom config file '{config_file}' is missing."
             click.echo(msg)
 
         sys.exit(-1)
@@ -392,8 +394,14 @@ def human_size(bytes, units=None):
     return str(bytes) + units[0] if bytes < 1024 else human_size(bytes >> 10, units[1:])
 
 
-def strfdelta(tdelta, fmt="{hours}:{minutes}:{seconds}"):
-    d = {"days": tdelta.days}
+def strfdelta(tdelta, fmt="{hours:{width}}:{minutes:{width}}:{seconds:{width}}"):
+    d = {
+        "days": tdelta.days,
+        "width": "02",
+    }
+    if tdelta.days > 0:
+        fmt = "{days} days " + fmt
+
     d["hours"], rem = divmod(tdelta.seconds, 3600)
     d["minutes"], d["seconds"] = divmod(rem, 60)
     return fmt.format(**d)
@@ -458,6 +466,9 @@ class RingBuffer:
             """return list of elements in correct order"""
             return self.data[self.cur :] + self.data[: self.cur]
 
+        def __len__(self):
+            return len(self.data)
+
     def append(self, x):
         """append an element at the end of the buffer"""
 
