@@ -1,25 +1,25 @@
 import unittest
 
-from aprsd import email
+from aprsd.plugins import email
 
 
 class TestEmail(unittest.TestCase):
     def test_get_email_from_shortcut(self):
-        email.CONFIG = {"shortcuts": {}}
+        email.CONFIG = {"aprsd": {"email": {"shortcuts": {}}}}
         email_address = "something@something.com"
-        addr = "-{}".format(email_address)
+        addr = f"-{email_address}"
         actual = email.get_email_from_shortcut(addr)
         self.assertEqual(addr, actual)
 
-        email.CONFIG = {"nothing": "nothing"}
+        email.CONFIG = {"aprsd": {"email": {"nothing": "nothing"}}}
         actual = email.get_email_from_shortcut(addr)
         self.assertEqual(addr, actual)
 
-        email.CONFIG = {"shortcuts": {"not_used": "empty"}}
+        email.CONFIG = {"aprsd": {"email": {"shortcuts": {"not_used": "empty"}}}}
         actual = email.get_email_from_shortcut(addr)
         self.assertEqual(addr, actual)
 
-        email.CONFIG = {"shortcuts": {"-wb": email_address}}
+        email.CONFIG = {"aprsd": {"email": {"shortcuts": {"-wb": email_address}}}}
         short = "-wb"
         actual = email.get_email_from_shortcut(short)
         self.assertEqual(email_address, actual)
